import { Utils, AppManager } from '@byondrnd/byond-web-lib';
import { CatalogManager } from './Managers/CatalogManager/CatalogManager';
import { ProductsManager } from './Managers/Scene/ProductsManager/ProductsManager';
import { EventSystem, EventSystemEventSignature, EventSystemEventDataSignature, IFavoriteProductList, IFavoriteSceneList, IFilter, IProduct, IScene, IApplication, IFacet } from './EventSystem/EventTypes';
import { SceneMetadataManager } from './Managers/SceneMetadataManager/SceneMetadataManager';
import ApolloClient from 'apollo-client';
import { NormalizedCacheObject } from 'apollo-cache-inmemory';
export declare class Visualizer extends EventSystem {
    appManager: AppManager;
    containerSelector: string;
    sceneSelector: string;
    containerElement: HTMLDivElement;
    experienceId: string;
    sceneId: string;
    catalogManager: CatalogManager;
    productsManager: ProductsManager;
    sceneMetadataManager: SceneMetadataManager;
    debug: boolean;
    pubs: Utils.RxUtils.Subscription[];
    initAndLoaded: boolean;
    showroomClient: ApolloClient<NormalizedCacheObject>;
    defaultProducts: {
        [application: string]: string;
    };
    defaultProduct: string;
    constructor(containerSelector: string, sceneSelector: string);
    initAndLoad(): Promise<void>;
    setScene(sceneId: string, preventDefaultProducts?: boolean, preventEvent?: boolean): Promise<void>;
    private initialProductDisplay;
    GetCurrentApplication(): IApplication;
    SetCurrentApplication(application: IApplication): IApplication;
    SetFilter(filters: IFacet[]): IFacet[];
    GetCurrentFilters(): IFacet[];
    getDisplayedProduct(application: IApplication): IProduct;
    getDisplayedProducts(): Array<IProduct>;
    GetProductList(): IProduct[];
    GetApplicationsList(): {
        application: string;
        image: string;
    }[];
    GetFilters(): IFilter[];
    addProductToFavorites(productSku: string, application: IApplication): IFavoriteProductList;
    removeProductFromFavorites(productSku: string, application: IApplication): IFavoriteProductList;
    getFavoriteProducts(): IFavoriteProductList;
    addFavoriteScene(): Promise<IFavoriteSceneList>;
    removeFavoriteScene(setId: string): IFavoriteSceneList;
    getFavoriteScenes(): IFavoriteSceneList;
    getSceneList(): IScene[];
    addProductToCart(product: IProduct): void;
    orderSample(product: IProduct): void;
    getCurrentSceneImage(): Promise<string>;
    displayProduct(productSku: string, application: IApplication, animateToProduct?: boolean): Promise<void>;
    displayScene(sceneId: string): Promise<void>;
    private getCurrentExperienceId;
    private getCurrentZoneIndex;
    private initCatalog;
    private initScene;
    private unRegisterEvents;
    private registerEvents;
    private loadScene;
    private navigate;
    private loadProps;
    emit(eventName: EventSystemEventSignature, ...args: EventSystemEventDataSignature): boolean;
}
